# Copyright (c) 2008 Brandon williams
#
# AUTHOR:
# Brandon Williams <opensource@subakutty.net>
#
# This file is part of TunnelManager
#
# TunnelManager is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 2, as published by
# the Free Software Foundation.
#
# TunnelManager is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Tunnelmanager; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#


import sys;
import gtk;


class StatusIcon(object):
    """This class represents the status box icon."""

    def __init__(self,gui):
        """The object constructor."""
        self.gui = gui;
        self.icon = gtk.status_icon_new_from_stock(gtk.STOCK_NETWORK);
        self.icon.set_tooltip(_("SSH Tunnel Manager"));
        self.icon.connect('popup-menu', self.displayMenu);
        self.icon.connect('activate', self.toggleHide);


    def displayMenu(self,widget,event_button,event_time):
        """Dynamically build the popup menu."""
        menu = gtk.Menu();

        keyMenu = gtk.Menu();
        self.addToMenu(keyMenu,_("Load "),gtk.STOCK_CONNECT,
                       self.gui.on_load_keys);
        self.addToMenu(keyMenu,_("Unload"),gtk.STOCK_DISCONNECT,
                       self.gui.on_unload_keys);
        self.addToMenu(keyMenu,_("View Agent"),gtk.STOCK_INFO,
                       self.gui.on_view_agent);

        
        keysItem = self.addToMenu(menu,_('Keys'),
                                  gtk.STOCK_DIALOG_AUTHENTICATION);
        keysItem.set_submenu(keyMenu);

        separator = gtk.SeparatorMenuItem();
        menu.append(separator);
        separator.show();

        for tunnel in self.gui.controller.tunnelList:
            if(tunnel.isActive):
                self.addToMenu(menu,tunnel.name, gtk.STOCK_YES,
                               self.gui.stopTunnel,tunnel);
            else:
                self.addToMenu(menu,tunnel.name, gtk.STOCK_NO,
                               self.gui.startTunnel,tunnel);

        separator = gtk.SeparatorMenuItem();
        menu.append(separator);
        separator.show();

        self.addToMenu(menu,_("Quit"), gtk.STOCK_QUIT, 
                       self.gui.on_quit);

        menu.popup(None, None, None, event_button, event_time);


    def addToMenu(self,menu,label,stock_id,handler=None,data=None):
        """Add an item to the menu."""
        if stock_id == gtk.STOCK_YES or stock_id == gtk.STOCK_NO:
            item = gtk.CheckMenuItem(label);
            item.set_active(stock_id == gtk.STOCK_YES);
        else:
            item = gtk.ImageMenuItem(label);
            image = gtk.image_new_from_stock(stock_id, gtk.ICON_SIZE_MENU);
            item.set_image(image);
        if(handler):
            if(data):
                item.connect('activate',handler,data);
            else:
                item.connect('activate',handler);
        menu.append(item);
        item.show();
        return item;


    def toggleHide(self,widget):
        """Unhide the tunnel manager, if it is hidden."""
        if(self.gui.mainWindow != None):
            if(not self.gui.is_visible or not self.gui.in_focus or
               self.gui.mainWindow.iconify_initially):
                self.gui.mainWindow.deiconify();
                self.gui.mainWindow.present();
            elif(self.gui.config.safeGetBoolean('GUI','showIcon') and
                 self.gui.config.safeGetBoolean('GUI','minToTray')):
                self.gui.destroyWindow();
            else:
                self.gui.mainWindow.iconify();
        else:
            self.gui.buildWindow();
